==> istio-model-v1beta1-5.11.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/L4MatchAttributesBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class L4MatchAttributesBuilder extends io.fabric8.istio.api.networking.v1beta1.L4MatchAttributesFluentImpl<io.fabric8.istio.api.networking.v1beta1.L4MatchAttributesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.networking.v1beta1.L4MatchAttributes,io.fabric8.istio.api.networking.v1beta1.L4MatchAttributesBuilder>{
  public L4MatchAttributesBuilder() {
    this(false);
  }
  public L4MatchAttributesBuilder(java.lang.Boolean validationEnabled) {
    this(new L4MatchAttributes(), validationEnabled);
  }
  public L4MatchAttributesBuilder(io.fabric8.istio.api.networking.v1beta1.L4MatchAttributesFluent<?> fluent) {
    this(fluent, false);
  }
  public L4MatchAttributesBuilder(io.fabric8.istio.api.networking.v1beta1.L4MatchAttributesFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new L4MatchAttributes(), validationEnabled);
  }
  public L4MatchAttributesBuilder(io.fabric8.istio.api.networking.v1beta1.L4MatchAttributesFluent<?> fluent,io.fabric8.istio.api.networking.v1beta1.L4MatchAttributes instance) {
    this(fluent, instance, false);
  }
  public L4MatchAttributesBuilder(io.fabric8.istio.api.networking.v1beta1.L4MatchAttributesFluent<?> fluent,io.fabric8.istio.api.networking.v1beta1.L4MatchAttributes instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDestinationSubnets(instance.getDestinationSubnets()); 
    fluent.withGateways(instance.getGateways()); 
    fluent.withPort(instance.getPort()); 
    fluent.withSourceLabels(instance.getSourceLabels()); 
    fluent.withSourceNamespace(instance.getSourceNamespace()); 
    fluent.withSourceSubnet(instance.getSourceSubnet()); 
    this.validationEnabled = validationEnabled; 
  }
  public L4MatchAttributesBuilder(io.fabric8.istio.api.networking.v1beta1.L4MatchAttributes instance) {
    this(instance,false);
  }
  public L4MatchAttributesBuilder(io.fabric8.istio.api.networking.v1beta1.L4MatchAttributes instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDestinationSubnets(instance.getDestinationSubnets()); 
    this.withGateways(instance.getGateways()); 
    this.withPort(instance.getPort()); 
    this.withSourceLabels(instance.getSourceLabels()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
    this.withSourceSubnet(instance.getSourceSubnet()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.networking.v1beta1.L4MatchAttributesFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.networking.v1beta1.L4MatchAttributes build() {
    L4MatchAttributes buildable = new L4MatchAttributes(fluent.getDestinationSubnets(),fluent.getGateways(),fluent.getPort(),fluent.getSourceLabels(),fluent.getSourceNamespace(),fluent.getSourceSubnet());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    L4MatchAttributesBuilder that = (L4MatchAttributesBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1beta1-6.1.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/L4MatchAttributesBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class L4MatchAttributesBuilder extends L4MatchAttributesFluentImpl<L4MatchAttributesBuilder> implements VisitableBuilder<L4MatchAttributes,L4MatchAttributesBuilder>{
  public L4MatchAttributesBuilder() {
    this(false);
  }
  public L4MatchAttributesBuilder(Boolean validationEnabled) {
    this(new L4MatchAttributes(), validationEnabled);
  }
  public L4MatchAttributesBuilder(L4MatchAttributesFluent<?> fluent) {
    this(fluent, false);
  }
  public L4MatchAttributesBuilder(L4MatchAttributesFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new L4MatchAttributes(), validationEnabled);
  }
  public L4MatchAttributesBuilder(L4MatchAttributesFluent<?> fluent,L4MatchAttributes instance) {
    this(fluent, instance, false);
  }
  public L4MatchAttributesBuilder(L4MatchAttributesFluent<?> fluent,L4MatchAttributes instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDestinationSubnets(instance.getDestinationSubnets()); 
    fluent.withGateways(instance.getGateways()); 
    fluent.withPort(instance.getPort()); 
    fluent.withSourceLabels(instance.getSourceLabels()); 
    fluent.withSourceNamespace(instance.getSourceNamespace()); 
    fluent.withSourceSubnet(instance.getSourceSubnet()); 
    this.validationEnabled = validationEnabled; 
  }
  public L4MatchAttributesBuilder(L4MatchAttributes instance) {
    this(instance,false);
  }
  public L4MatchAttributesBuilder(L4MatchAttributes instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDestinationSubnets(instance.getDestinationSubnets()); 
    this.withGateways(instance.getGateways()); 
    this.withPort(instance.getPort()); 
    this.withSourceLabels(instance.getSourceLabels()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
    this.withSourceSubnet(instance.getSourceSubnet()); 
    this.validationEnabled = validationEnabled; 
  }
  L4MatchAttributesFluent<?> fluent;
  Boolean validationEnabled;
  public L4MatchAttributes build() {
    L4MatchAttributes buildable = new L4MatchAttributes(fluent.getDestinationSubnets(),fluent.getGateways(),fluent.getPort(),fluent.getSourceLabels(),fluent.getSourceNamespace(),fluent.getSourceSubnet());
    return buildable;
  }
  
}
